# --
# Kernel/Config.pm - Config file for OTRS kernel
# Copyright (C) 2001-2003 Martin Edenhofer <martin+code@otrs.org>
# --
# $Id: Config.pm.dist,v 1.6 2003/03/02 08:56:36 martin Exp $
# --
# This software comes with ABSOLUTELY NO WARRANTY. For details, see 
# the enclosed file COPYING for license information (GPL). If you 
# did not receive this file, see http://www.gnu.org/licenses/gpl.txt.
# --
#  Note: 
#
#  -->> OTRS does have a lot of config settings. For more settings 
#       (Notifications, TicketViewAccelerator, TicketNumberGenerator, 
#       LDAP, PostMaster, Session, Preferences, ...) see 
#       Kernel/Config/Defaults.pm and copy your wanted lines into "this" 
#       config file. This file will not be changed on update! 
#
# -- 
package Kernel::Config;
# --
sub Load {
    my $Self = shift;
    # ---------------------------------------------------- #
    # ---------------------------------------------------- #
    #                                                      #
    #         Start of your own config options!!!          #
    #                                                      #
    # ---------------------------------------------------- #
    # ---------------------------------------------------- #

    # ---------------------------------------------------- #
    # system data                                          #
    # ---------------------------------------------------- #
    # SecureMode
    # (Enable this so you can't use the installer.pl)
    $Self->{SecureMode} = 1;
    # SystemID
    # (The identify of the system. Each ticket number and
    # each http session id starts with this number)
    $Self->{SystemID} = 13; 
    # TicketHook 
    # (To set the Ticket identifier. Some people want to 
    # set this to e. g. 'Call#', 'MyTicket#' or 'TN'.)
    $Self->{TicketHook} = 'PSIC Lab Request #';
    # FQDN
    # (Full qualified domain name of your system.)
    $Self->{FQDN} = 'wnpsitw1.psic.gm.com';

    # AdminEmail 
    # (Email of the system admin.)
    $Self->{AdminEmail} = 'request@wnpsitw1.psic.gm.com';

    # Organization
    # (If this is anything other than '', then the email will have an
    # Organization X-Header)
    $Self->{Organization} = 'PSIC Lab';

    # CheckMXRecord
    # (Check mx recorde of used email addresses)
    $Self->{CheckMXRecord} = 0;

    # CheckEmailAddresses
    # (Check used email addresses)
    $Self->{CheckEmailAddresses} = 0;

    # ShowMotd
    # (show message of the day in login screen)
    $Self->{ShowMotd} = 1;

    # Ticket number generator.  See the ~/Kernel/Config/Defaults.pm for info
    $Self->{TicketNumberGenerator} = 'Kernel::System::Ticket::Number::AutoIncrement';

    # This part allows us to have the customer select their queue
    #  ==========================================================
    # CustomerPanelSelectionType
    # (To: seection type. Queue => show all queues, SystemAddress => show all system
    # addresses;) [Queue|SystemAddress]
    $Self->{CustomerPanelSelectionType} = 'Queue';
    #$Self->{CustomerPanelSelectionType} = 'SystemAddress';

    # CustomerPanelSelectionString
    # (String for To: selection.)
    # use this for CustomerPanelSelectionType = Queue
    #$Self->{CustomerPanelSelectionString} = 'Queue: <Queue> - <QueueComment>';
    # use this for CustomerPanelSelectionType = SystemAddress
    $Self->{CustomerPanelSelectionString} = 'Queue: <Queue> - <QueueComment>';
    # ==========================================================






    # ---------------------------------------------------- #
    # database settings                                    #
    # ---------------------------------------------------- #
    # DatabaseHost
    # (The database host.)
    $Self->{DatabaseHost} = 'localhost';
    # Database
    # (The database name.)
    $Self->{Database} = 'otrs_test';
    # DatabaseUser
    # (The database user.)
    $Self->{DatabaseUser} = 'root';
    # DatabasePw
    # (The password of database user.)
    $Self->{DatabasePw} = 'shalafi';
    # DatabaseDSN
    # (The database DSN for MySQL ==> more: "man DBD::mysql")
    $Self->{DatabaseDSN} = "DBI:mysql:database=$Self->{Database};host=$Self->{DatabaseHost};";
    # (The database DSN for PostgrSQL ==> more: "man DBD::Pg") 
#    $Self->{DatabaseDSN} = "DBI:Pg:dbname=$Self->{Database};";

    # ---------------------------------------------------- #
    # fs root directory
    # ---------------------------------------------------- #
    $Self->{Home} = 'd:/otrs';

    # **************************************************** #
    # insert your own config settings "here"               # 
    # config settings taken from Kernel/Config/Defaults.pm # 
    # **************************************************** #
    # $Self->{SessionUseCookie} = 0;

    # **************************************************** #

    # ---------------------------------------------------- #
    # data inserted by installer                           #
    # ---------------------------------------------------- #
    # $DIBI$
    $Self->{LogModule::LogFile} = 'D:\otrs\var\log\otrs.log';
    $Self->{DefaultLanguage} = 'en';
    $Self->{DefaultCharset} = 'iso-8859-1';

    
    # -----------------------------------------------------#
    # Sendmail
    # -----------------------------------------------------#
    # SendmailModule
    # (Where is sendmail located and some options.
    # See 'man sendmail' for details. Or use the SMTP backend.) 
    $Self->{'SendmailModule'} = 'Kernel::System::Email::Sendmail';
    $Self->{'SendmailModule::CMD'} = '/usr/sbin/sendmail -t -i -f ';
    # -----------------------------------------------------#
    # directories
    # -----------------------------------------------------#
    $Self->{Home} = 'd:/otrs';
    $Self->{CounterLog} = '<OTRS_CONFIG_Home>/var/log/TicketCounter.log';
    $Self->{ArticleDir} = '<OTRS_CONFIG_Home>/var/article';
    $Self->{StatsPicDir} = '<OTRS_CONFIG_Home>/var/pics/stats';
    $Self->{TemplateDir} = '<OTRS_CONFIG_Home>/Kernel/Output';
    $Self->{TempDir} = '<OTRS_CONFIG_Home>/var/tmp';
    # ----------------------------------------------------#
    # LogModule                                           #
    # ----------------------------------------------------#
    $Self->{LogModule} = 'Kernel::System::Log::File';
    # -----------------------------------------------------#
    # own config settings                                  #
    # config settings taken from Kernel/Config/Defaults.pm #
    # -----------------------------------------------------#
    # $Self->{SessionUseCookie} = 0;
    $Self->{SessionModule} = 'Kernel::System::AuthSession::DB';










    # ---------------------------------------------------- #
    # ---------------------------------------------------- #
    #                                                      #
    #           End of your own config options!!!          #
    #                                                      #
    # ---------------------------------------------------- #
    # ---------------------------------------------------- #
}

# ---------------------------------------------------- #
# needed system stuff (don't edit this)                #
# ---------------------------------------------------- #
use strict;
use vars qw(@ISA $VERSION);
use Kernel::Config::Defaults;
push (@ISA, 'Kernel::Config::Defaults');
$VERSION = '$Revision: 1.6 $';
$VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
# -----------------------------------------------------#

1;
